# coding: utf-8

# flake8: noqa

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.1.0"

# Define package exports
__all__ = [
    "AnalyticsApi",
    "CompletionsApi",
    "GenerationsApi",
    "ImagesApi",
    "ModelsApi",
    "ModerationsApi",
    "VideoApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "BenchmarkId",
    "ChatCompletionsRequest",
    "ChatCompletionsRequestReasoning",
    "ChatCompletionsRequestToolChoice",
    "ChatCompletionsResponse",
    "ChatMessage",
    "ChatMessageAssistant",
    "ChatMessageSystem",
    "ChatMessageTool",
    "ChatMessageUser",
    "GatewayChatChoice",
    "GatewayChatChoiceMessage",
    "GatewayError",
    "GatewayErrorMeta",
    "GatewayGenerationRecord",
    "GatewayHealthProvider",
    "GatewayHealthResponse",
    "GatewayHealthResponseOverall",
    "GatewayHealthResponseScope",
    "GatewayImageData",
    "GatewayMetadata",
    "GatewayModel",
    "GatewayModelProvider",
    "GatewayOrganisation",
    "GatewayResponseEnvelope",
    "GatewayUsage",
    "ImageGenerationRequest",
    "ImageGenerationResponse",
    "MessageContent",
    "MessageContentImageUrl",
    "MessageContentImageUrlImageUrl",
    "MessageContentInputAudio",
    "MessageContentInputAudioInputAudio",
    "MessageContentInputVideo",
    "MessageContentPart",
    "MessageContentText",
    "ModelId",
    "ModelListResponse",
    "ModelsGetIncludeEndpointsParameter",
    "ModelsGetOrganisationParameter",
    "ModelsGetProviderParameter",
    "ModerationInputContentItem",
    "ModerationInputImageUrlItem",
    "ModerationInputImageUrlItemImageUrl",
    "ModerationInputTextItem",
    "ModerationRequest",
    "ModerationRequestInput",
    "ModerationResponse",
    "ModerationResult",
    "OrganisationId",
    "ToolCall",
    "ToolCallFunction",
    "ToolCallPart",
    "VideoGenerationRequest",
    "VideoGenerationResponse",
]

# import apis into sdk package
from ai_stats_generated.api.analytics_api import AnalyticsApi as AnalyticsApi
from ai_stats_generated.api.completions_api import CompletionsApi as CompletionsApi
from ai_stats_generated.api.generations_api import GenerationsApi as GenerationsApi
from ai_stats_generated.api.images_api import ImagesApi as ImagesApi
from ai_stats_generated.api.models_api import ModelsApi as ModelsApi
from ai_stats_generated.api.moderations_api import ModerationsApi as ModerationsApi
from ai_stats_generated.api.video_api import VideoApi as VideoApi

# import ApiClient
from ai_stats_generated.api_response import ApiResponse as ApiResponse
from ai_stats_generated.api_client import ApiClient as ApiClient
from ai_stats_generated.configuration import Configuration as Configuration
from ai_stats_generated.exceptions import OpenApiException as OpenApiException
from ai_stats_generated.exceptions import ApiTypeError as ApiTypeError
from ai_stats_generated.exceptions import ApiValueError as ApiValueError
from ai_stats_generated.exceptions import ApiKeyError as ApiKeyError
from ai_stats_generated.exceptions import ApiAttributeError as ApiAttributeError
from ai_stats_generated.exceptions import ApiException as ApiException

# import models into sdk package
from ai_stats_generated.models.benchmark_id import BenchmarkId as BenchmarkId
from ai_stats_generated.models.chat_completions_request import ChatCompletionsRequest as ChatCompletionsRequest
from ai_stats_generated.models.chat_completions_request_reasoning import ChatCompletionsRequestReasoning as ChatCompletionsRequestReasoning
from ai_stats_generated.models.chat_completions_request_tool_choice import ChatCompletionsRequestToolChoice as ChatCompletionsRequestToolChoice
from ai_stats_generated.models.chat_completions_response import ChatCompletionsResponse as ChatCompletionsResponse
from ai_stats_generated.models.chat_message import ChatMessage as ChatMessage
from ai_stats_generated.models.chat_message_assistant import ChatMessageAssistant as ChatMessageAssistant
from ai_stats_generated.models.chat_message_system import ChatMessageSystem as ChatMessageSystem
from ai_stats_generated.models.chat_message_tool import ChatMessageTool as ChatMessageTool
from ai_stats_generated.models.chat_message_user import ChatMessageUser as ChatMessageUser
from ai_stats_generated.models.gateway_chat_choice import GatewayChatChoice as GatewayChatChoice
from ai_stats_generated.models.gateway_chat_choice_message import GatewayChatChoiceMessage as GatewayChatChoiceMessage
from ai_stats_generated.models.gateway_error import GatewayError as GatewayError
from ai_stats_generated.models.gateway_error_meta import GatewayErrorMeta as GatewayErrorMeta
from ai_stats_generated.models.gateway_generation_record import GatewayGenerationRecord as GatewayGenerationRecord
from ai_stats_generated.models.gateway_health_provider import GatewayHealthProvider as GatewayHealthProvider
from ai_stats_generated.models.gateway_health_response import GatewayHealthResponse as GatewayHealthResponse
from ai_stats_generated.models.gateway_health_response_overall import GatewayHealthResponseOverall as GatewayHealthResponseOverall
from ai_stats_generated.models.gateway_health_response_scope import GatewayHealthResponseScope as GatewayHealthResponseScope
from ai_stats_generated.models.gateway_image_data import GatewayImageData as GatewayImageData
from ai_stats_generated.models.gateway_metadata import GatewayMetadata as GatewayMetadata
from ai_stats_generated.models.gateway_model import GatewayModel as GatewayModel
from ai_stats_generated.models.gateway_model_provider import GatewayModelProvider as GatewayModelProvider
from ai_stats_generated.models.gateway_organisation import GatewayOrganisation as GatewayOrganisation
from ai_stats_generated.models.gateway_response_envelope import GatewayResponseEnvelope as GatewayResponseEnvelope
from ai_stats_generated.models.gateway_usage import GatewayUsage as GatewayUsage
from ai_stats_generated.models.image_generation_request import ImageGenerationRequest as ImageGenerationRequest
from ai_stats_generated.models.image_generation_response import ImageGenerationResponse as ImageGenerationResponse
from ai_stats_generated.models.message_content import MessageContent as MessageContent
from ai_stats_generated.models.message_content_image_url import MessageContentImageUrl as MessageContentImageUrl
from ai_stats_generated.models.message_content_image_url_image_url import MessageContentImageUrlImageUrl as MessageContentImageUrlImageUrl
from ai_stats_generated.models.message_content_input_audio import MessageContentInputAudio as MessageContentInputAudio
from ai_stats_generated.models.message_content_input_audio_input_audio import MessageContentInputAudioInputAudio as MessageContentInputAudioInputAudio
from ai_stats_generated.models.message_content_input_video import MessageContentInputVideo as MessageContentInputVideo
from ai_stats_generated.models.message_content_part import MessageContentPart as MessageContentPart
from ai_stats_generated.models.message_content_text import MessageContentText as MessageContentText
from ai_stats_generated.models.model_id import ModelId as ModelId
from ai_stats_generated.models.model_list_response import ModelListResponse as ModelListResponse
from ai_stats_generated.models.models_get_include_endpoints_parameter import ModelsGetIncludeEndpointsParameter as ModelsGetIncludeEndpointsParameter
from ai_stats_generated.models.models_get_organisation_parameter import ModelsGetOrganisationParameter as ModelsGetOrganisationParameter
from ai_stats_generated.models.models_get_provider_parameter import ModelsGetProviderParameter as ModelsGetProviderParameter
from ai_stats_generated.models.moderation_input_content_item import ModerationInputContentItem as ModerationInputContentItem
from ai_stats_generated.models.moderation_input_image_url_item import ModerationInputImageUrlItem as ModerationInputImageUrlItem
from ai_stats_generated.models.moderation_input_image_url_item_image_url import ModerationInputImageUrlItemImageUrl as ModerationInputImageUrlItemImageUrl
from ai_stats_generated.models.moderation_input_text_item import ModerationInputTextItem as ModerationInputTextItem
from ai_stats_generated.models.moderation_request import ModerationRequest as ModerationRequest
from ai_stats_generated.models.moderation_request_input import ModerationRequestInput as ModerationRequestInput
from ai_stats_generated.models.moderation_response import ModerationResponse as ModerationResponse
from ai_stats_generated.models.moderation_result import ModerationResult as ModerationResult
from ai_stats_generated.models.organisation_id import OrganisationId as OrganisationId
from ai_stats_generated.models.tool_call import ToolCall as ToolCall
from ai_stats_generated.models.tool_call_function import ToolCallFunction as ToolCallFunction
from ai_stats_generated.models.tool_call_part import ToolCallPart as ToolCallPart
from ai_stats_generated.models.video_generation_request import VideoGenerationRequest as VideoGenerationRequest
from ai_stats_generated.models.video_generation_response import VideoGenerationResponse as VideoGenerationResponse

