# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class GatewayGenerationRecord(BaseModel):
    """
    GatewayGenerationRecord
    """ # noqa: E501
    request_id: StrictStr
    team_id: StrictStr
    app_id: Optional[StrictStr] = None
    app_title: Optional[StrictStr] = None
    referer: Optional[StrictStr] = None
    endpoint: StrictStr
    model_id: Optional[StrictStr] = None
    provider: Optional[StrictStr] = None
    native_response_id: Optional[StrictStr] = None
    stream: Optional[StrictBool] = None
    byok: Optional[StrictBool] = None
    status_code: Optional[StrictInt] = None
    success: StrictBool
    error_code: Optional[StrictStr] = None
    error_message: Optional[StrictStr] = None
    before: Optional[Dict[str, Any]] = None
    execute: Optional[Dict[str, Any]] = None
    latency_ms: Optional[Union[StrictFloat, StrictInt]] = None
    generation_ms: Optional[Union[StrictFloat, StrictInt]] = None
    usage: Optional[Dict[str, Any]] = None
    cost_nanos: Optional[StrictInt] = None
    currency: Optional[StrictStr] = None
    pricing_lines: Optional[List[Dict[str, Any]]] = None
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["request_id", "team_id", "app_id", "app_title", "referer", "endpoint", "model_id", "provider", "native_response_id", "stream", "byok", "status_code", "success", "error_code", "error_message", "before", "execute", "latency_ms", "generation_ms", "usage", "cost_nanos", "currency", "pricing_lines"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GatewayGenerationRecord from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GatewayGenerationRecord from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "request_id": obj.get("request_id"),
            "team_id": obj.get("team_id"),
            "app_id": obj.get("app_id"),
            "app_title": obj.get("app_title"),
            "referer": obj.get("referer"),
            "endpoint": obj.get("endpoint"),
            "model_id": obj.get("model_id"),
            "provider": obj.get("provider"),
            "native_response_id": obj.get("native_response_id"),
            "stream": obj.get("stream"),
            "byok": obj.get("byok"),
            "status_code": obj.get("status_code"),
            "success": obj.get("success"),
            "error_code": obj.get("error_code"),
            "error_message": obj.get("error_message"),
            "before": obj.get("before"),
            "execute": obj.get("execute"),
            "latency_ms": obj.get("latency_ms"),
            "generation_ms": obj.get("generation_ms"),
            "usage": obj.get("usage"),
            "cost_nanos": obj.get("cost_nanos"),
            "currency": obj.get("currency"),
            "pricing_lines": obj.get("pricing_lines")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


