# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class OrganisationId(str, Enum):
    """
    Organisation identifier.
    """

    """
    allowed enum values
    """
    AI21 = 'ai21'
    AMAZON = 'amazon'
    ANTHROPIC = 'anthropic'
    BAIDU = 'baidu'
    BLACK_MINUS_FOREST_MINUS_LABS = 'black-forest-labs'
    BYTEDANCE = 'bytedance'
    COHERE = 'cohere'
    DEEPSEEK = 'deepseek'
    ELEVEN_MINUS_LABS = 'eleven-labs'
    GOOGLE = 'google'
    IBM = 'ibm'
    INCLUSIONAI = 'inclusionai'
    LG = 'lg'
    META = 'meta'
    MICROSOFT = 'microsoft'
    MINIMAX = 'minimax'
    MISTRAL = 'mistral'
    MOONSHOTAI = 'moonshotai'
    NOUS = 'nous'
    NVIDIA = 'nvidia'
    OPENAI = 'openai'
    PERPLEXITY = 'perplexity'
    QWEN = 'qwen'
    SUNO = 'suno'
    X_MINUS_AI = 'x-ai'
    Z_MINUS_AI = 'z-ai'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of OrganisationId from a JSON string"""
        return cls(json.loads(json_str))


