# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List
from ai_stats_generated.models.gateway_health_provider import GatewayHealthProvider
from ai_stats_generated.models.gateway_health_response_overall import GatewayHealthResponseOverall
from ai_stats_generated.models.gateway_health_response_scope import GatewayHealthResponseScope
from typing import Optional, Set
from typing_extensions import Self

class GatewayHealthResponse(BaseModel):
    """
    GatewayHealthResponse
    """ # noqa: E501
    ok: StrictBool
    window_minutes: StrictInt
    scope: GatewayHealthResponseScope
    overall: GatewayHealthResponseOverall
    providers: List[GatewayHealthProvider]
    generated_at: StrictInt = Field(description="Unix timestamp in milliseconds.")
    __properties: ClassVar[List[str]] = ["ok", "window_minutes", "scope", "overall", "providers", "generated_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GatewayHealthResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of scope
        if self.scope:
            _dict['scope'] = self.scope.to_dict()
        # override the default output from pydantic by calling `to_dict()` of overall
        if self.overall:
            _dict['overall'] = self.overall.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in providers (list)
        _items = []
        if self.providers:
            for _item_providers in self.providers:
                if _item_providers:
                    _items.append(_item_providers.to_dict())
            _dict['providers'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GatewayHealthResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "ok": obj.get("ok"),
            "window_minutes": obj.get("window_minutes"),
            "scope": GatewayHealthResponseScope.from_dict(obj["scope"]) if obj.get("scope") is not None else None,
            "overall": GatewayHealthResponseOverall.from_dict(obj["overall"]) if obj.get("overall") is not None else None,
            "providers": [GatewayHealthProvider.from_dict(_item) for _item in obj["providers"]] if obj.get("providers") is not None else None,
            "generated_at": obj.get("generated_at")
        })
        return _obj


