# coding: utf-8

# flake8: noqa
"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from ai_stats_generated.models.benchmark_id import BenchmarkId
from ai_stats_generated.models.chat_completions_request import ChatCompletionsRequest
from ai_stats_generated.models.chat_completions_request_reasoning import ChatCompletionsRequestReasoning
from ai_stats_generated.models.chat_completions_request_tool_choice import ChatCompletionsRequestToolChoice
from ai_stats_generated.models.chat_completions_response import ChatCompletionsResponse
from ai_stats_generated.models.chat_message import ChatMessage
from ai_stats_generated.models.chat_message_assistant import ChatMessageAssistant
from ai_stats_generated.models.chat_message_system import ChatMessageSystem
from ai_stats_generated.models.chat_message_tool import ChatMessageTool
from ai_stats_generated.models.chat_message_user import ChatMessageUser
from ai_stats_generated.models.gateway_chat_choice import GatewayChatChoice
from ai_stats_generated.models.gateway_chat_choice_message import GatewayChatChoiceMessage
from ai_stats_generated.models.gateway_error import GatewayError
from ai_stats_generated.models.gateway_error_meta import GatewayErrorMeta
from ai_stats_generated.models.gateway_generation_record import GatewayGenerationRecord
from ai_stats_generated.models.gateway_health_provider import GatewayHealthProvider
from ai_stats_generated.models.gateway_health_response import GatewayHealthResponse
from ai_stats_generated.models.gateway_health_response_overall import GatewayHealthResponseOverall
from ai_stats_generated.models.gateway_health_response_scope import GatewayHealthResponseScope
from ai_stats_generated.models.gateway_image_data import GatewayImageData
from ai_stats_generated.models.gateway_metadata import GatewayMetadata
from ai_stats_generated.models.gateway_model import GatewayModel
from ai_stats_generated.models.gateway_model_provider import GatewayModelProvider
from ai_stats_generated.models.gateway_organisation import GatewayOrganisation
from ai_stats_generated.models.gateway_response_envelope import GatewayResponseEnvelope
from ai_stats_generated.models.gateway_usage import GatewayUsage
from ai_stats_generated.models.image_generation_request import ImageGenerationRequest
from ai_stats_generated.models.image_generation_response import ImageGenerationResponse
from ai_stats_generated.models.message_content import MessageContent
from ai_stats_generated.models.message_content_image_url import MessageContentImageUrl
from ai_stats_generated.models.message_content_image_url_image_url import MessageContentImageUrlImageUrl
from ai_stats_generated.models.message_content_input_audio import MessageContentInputAudio
from ai_stats_generated.models.message_content_input_audio_input_audio import MessageContentInputAudioInputAudio
from ai_stats_generated.models.message_content_input_video import MessageContentInputVideo
from ai_stats_generated.models.message_content_part import MessageContentPart
from ai_stats_generated.models.message_content_text import MessageContentText
from ai_stats_generated.models.model_id import ModelId
from ai_stats_generated.models.model_list_response import ModelListResponse
from ai_stats_generated.models.models_get_include_endpoints_parameter import ModelsGetIncludeEndpointsParameter
from ai_stats_generated.models.models_get_organisation_parameter import ModelsGetOrganisationParameter
from ai_stats_generated.models.models_get_provider_parameter import ModelsGetProviderParameter
from ai_stats_generated.models.moderation_input_content_item import ModerationInputContentItem
from ai_stats_generated.models.moderation_input_image_url_item import ModerationInputImageUrlItem
from ai_stats_generated.models.moderation_input_image_url_item_image_url import ModerationInputImageUrlItemImageUrl
from ai_stats_generated.models.moderation_input_text_item import ModerationInputTextItem
from ai_stats_generated.models.moderation_request import ModerationRequest
from ai_stats_generated.models.moderation_request_input import ModerationRequestInput
from ai_stats_generated.models.moderation_response import ModerationResponse
from ai_stats_generated.models.moderation_result import ModerationResult
from ai_stats_generated.models.organisation_id import OrganisationId
from ai_stats_generated.models.tool_call import ToolCall
from ai_stats_generated.models.tool_call_function import ToolCallFunction
from ai_stats_generated.models.tool_call_part import ToolCallPart
from ai_stats_generated.models.video_generation_request import VideoGenerationRequest
from ai_stats_generated.models.video_generation_response import VideoGenerationResponse

